// Copyright 2021 Cargill Incorporated
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

use super::schema::*;

#[derive(Insertable, Identifiable, AsChangeset)]
#[cfg_attr(test, derive(Debug, PartialEq))]
#[table_name = "scabbard_commit_hash"]
#[primary_key(circuit_id, service_id)]
pub struct NewCommitHash<'a> {
    pub circuit_id: &'a str,
    pub service_id: &'a str,
    pub commit_hash: &'a str,
}
